@@ -224,21 +224,24 @@ class TestBuild:
         post_request.assert_called_with(
             api_build_url,
             mocker.ANY,
-            [
-                {
-                    "git_repo": build_attrs["git_repo"],
-                    "git_ref": build_attrs["git_ref"],
-                    "toolchain": build_attrs["toolchain"],
-                    "target_arch": build_attrs["target_arch"],
-                    "kconfig": [build_attrs["kconfig"]],
-                    "build_name": build_attrs["build_name"],
-                    "client_token": mocker.ANY,
-                    "environment": {},
-                    "targets": [],
-                    "make_variables": {},
-                    "kernel_image": build_attrs["kernel_image"],
-                }
-            ],
+            {
+                "builds": [
+                    {
+                        "git_repo": build_attrs["git_repo"],
+                        "git_ref": build_attrs["git_ref"],
+                        "toolchain": build_attrs["toolchain"],
+                        "target_arch": build_attrs["target_arch"],
+                        "kconfig": [build_attrs["kconfig"]],
+                        "build_name": build_attrs["build_name"],
+                        "client_token": mocker.ANY,
+                        "environment": {},
+                        "targets": [],
+                        "make_variables": {},
+                        "kernel_image": build_attrs["kernel_image"],
+                    },
+                ],
+                "patches": {},
+            },
         )
 
     def test_submit_build_git_sha(self, build, build_attrs, mocker):
@@ -253,21 +256,24 @@ class TestBuild:
         post_request.assert_called_with(
             api_build_url,
             mocker.ANY,
-            [
-                {
-                    "git_repo": build_attrs["git_repo"],
-                    "git_sha": "badbee",
-                    "toolchain": build_attrs["toolchain"],
-                    "target_arch": build_attrs["target_arch"],
-                    "kconfig": [build_attrs["kconfig"]],
-                    "build_name": build_attrs["build_name"],
-                    "client_token": mocker.ANY,
-                    "environment": {},
-                    "targets": [],
-                    "make_variables": {},
-                    "kernel_image": build_attrs["kernel_image"],
-                }
-            ],
+            {
+                "builds": [
+                    {
+                        "git_repo": build_attrs["git_repo"],
+                        "git_sha": "badbee",
+                        "toolchain": build_attrs["toolchain"],
+                        "target_arch": build_attrs["target_arch"],
+                        "kconfig": [build_attrs["kconfig"]],
+                        "build_name": build_attrs["build_name"],
+                        "client_token": mocker.ANY,
+                        "environment": {},
+                        "targets": [],
+                        "make_variables": {},
+                        "kernel_image": build_attrs["kernel_image"],
+                    },
+                ],
+                "patches": {},
+            },
         )
 
     def test_client_token(self, build):
@@ -294,21 +300,24 @@ class TestBuild:
         post_request.assert_called_with(
             api_build_url,
             mocker.ANY,
-            [
-                {
-                    "git_repo": build_attrs["git_repo"],
-                    "git_sha": "badbee",
-                    "toolchain": build_attrs["toolchain"],
-                    "target_arch": build_attrs["target_arch"],
-                    "kconfig": [build_attrs["kconfig"]],
-                    "build_name": build_attrs["build_name"],
-                    "client_token": mocker.ANY,
-                    "environment": build_attrs["environment"],
-                    "targets": [],
-                    "make_variables": {},
-                    "kernel_image": build_attrs["kernel_image"],
-                }
-            ],
+            {
+                "builds": [
+                    {
+                        "git_repo": build_attrs["git_repo"],
+                        "git_sha": "badbee",
+                        "toolchain": build_attrs["toolchain"],
+                        "target_arch": build_attrs["target_arch"],
+                        "kconfig": [build_attrs["kconfig"]],
+                        "build_name": build_attrs["build_name"],
+                        "client_token": mocker.ANY,
+                        "environment": build_attrs["environment"],
+                        "targets": [],
+                        "make_variables": {},
+                        "kernel_image": build_attrs["kernel_image"],
+                    }
+                ],
+                "patches": {},
+            },
         )
 
     def test_submit_build_targets(self, build, build_attrs, mocker):
@@ -325,21 +334,24 @@ class TestBuild:
         post_request.assert_called_with(
             api_build_url,
             mocker.ANY,
-            [
-                {
-                    "git_repo": build_attrs["git_repo"],
-                    "git_sha": "badbee",
-                    "toolchain": build_attrs["toolchain"],
-                    "target_arch": build_attrs["target_arch"],
-                    "kconfig": [build_attrs["kconfig"]],
-                    "build_name": build_attrs["build_name"],
-                    "client_token": mocker.ANY,
-                    "targets": build_attrs["targets"],
-                    "environment": {},
-                    "make_variables": {},
-                    "kernel_image": build_attrs["kernel_image"],
-                }
-            ],
+            {
+                "builds": [
+                    {
+                        "git_repo": build_attrs["git_repo"],
+                        "git_sha": "badbee",
+                        "toolchain": build_attrs["toolchain"],
+                        "target_arch": build_attrs["target_arch"],
+                        "kconfig": [build_attrs["kconfig"]],
+                        "build_name": build_attrs["build_name"],
+                        "client_token": mocker.ANY,
+                        "targets": build_attrs["targets"],
+                        "environment": {},
+                        "make_variables": {},
+                        "kernel_image": build_attrs["kernel_image"],
+                    },
+                ],
+                "patches": {},
+            },
         )
 
     def test_submit_build_make_variables(self, build, build_attrs, mocker):
@@ -356,21 +368,24 @@ class TestBuild:
         post_request.assert_called_with(
             api_build_url,
             mocker.ANY,
-            [
-                {
-                    "git_repo": build_attrs["git_repo"],
-                    "git_sha": "badbee",
-                    "toolchain": build_attrs["toolchain"],
-                    "target_arch": build_attrs["target_arch"],
-                    "kconfig": [build_attrs["kconfig"]],
-                    "build_name": build_attrs["build_name"],
-                    "client_token": mocker.ANY,
-                    "targets": [],
-                    "environment": {},
-                    "make_variables": {"W": "12", "LLVM": "1"},
-                    "kernel_image": build_attrs["kernel_image"],
-                }
-            ],
+            {
+                "builds": [
+                    {
+                        "git_repo": build_attrs["git_repo"],
+                        "git_sha": "badbee",
+                        "toolchain": build_attrs["toolchain"],
+                        "target_arch": build_attrs["target_arch"],
+                        "kconfig": [build_attrs["kconfig"]],
+                        "build_name": build_attrs["build_name"],
+                        "client_token": mocker.ANY,
+                        "targets": [],
+                        "environment": {},
+                        "make_variables": {"W": "12", "LLVM": "1"},
+                        "kernel_image": build_attrs["kernel_image"],
+                    },
+                ],
+                "patches": {},
+            },
         )
 
 
@@ -667,7 +682,7 @@ class TestBuildSet:
             },
         ]
         data = [
-            dict(**builds[i].generate_build_request(), **server_data[i])
+            dict(**builds[i].generate_build_request()[0], **server_data[i])
             for i in range(len(builds))
         ]
         response._content = json.dumps(list(reversed(data))).encode()
