@@ -21,8 +21,8 @@ import uuid
 from urllib.parse import urlparse
 
 
-# We will poll for status change for an average duration of 180 minutes
-state_timeout = 10800  # 60 * 180
+# We will poll for status change for an average duration of 240 minutes
+state_timeout = 14400  # 60 * 240
 delay_status_update = int(os.getenv("TUXSUITE_DELAY_STATUS_UPDATE", "29")) + 1
 
 
@@ -847,6 +847,12 @@ class Test(HeadersMixin):
         return self.status
 
     def watch(self, iterator=False):
+        """
+        Wait for the test to finish. Whenever the state changes, yielding the
+        new state).
+
+        Will timeout after `state_timeout` seconds.
+        """
         waiting_states = {
             "waiting": BuildState(
                 build=self,
@@ -870,7 +876,7 @@ class Test(HeadersMixin):
                 cli_color="cyan",
             ),
         }
-
+        timeout = time.time() + state_timeout
         previous_state = None
         while True:
             self.status = self.get()
@@ -882,6 +888,10 @@ class Test(HeadersMixin):
                     break
                 else:
                     assert 0
+            elif time.time() >= timeout:
+                raise tuxsuite.exceptions.Timeout(
+                    f"Test timed out after {state_timeout/60} minutes; abandoning"
+                )
             elif iterator:
                 yield
 
